%define anolis_release 2
%bcond_without python3

Summary: Utility for determining file types
Name: file
Version: 5.44
Release: %{anolis_release}%{?dist}
License: BSD
Source0: http://ftp.astron.com/pub/file/file-%{version}.tar.gz

# Upstream says it's up to distributions to add a way to support local-magic.
Patch1: 0001-Updated-and-synchronize-low-version-changes.patch
Patch2: 0002-readelf-remove-limit-check.patch

URL: https://www.darwinsys.com/file/
Requires: %{name}-libs = %{version}-%{release}
BuildRequires: zlib-devel
BuildRequires: bzip2-devel
BuildRequires: xz-devel
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: libtool
BuildRequires: make

%description
The file command is used to identify a particular file according to the
type of data contained by the file.  File can identify many different
file types, including ELF binaries, system libraries, RPM packages, and
different graphics formats.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package libs
Summary: Libraries for applications using libmagic
License: BSD

%description libs

Libraries for applications using libmagic.

%package devel
Summary:  Libraries and header files for file development
Requires: file-libs = %{version}-%{release}

%description devel
The file-devel package contains the header files and libmagic library
necessary for developing programs using libmagic.

%package static
Summary: Static library for file development
Requires: file-devel = %{version}-%{release}

%description static
The file-static package contains the static version of the libmagic library.

%if %{with python3}
%package -n python3-file-magic
Summary: Python 3 bindings for the libmagic API
BuildRequires: python3-devel
BuildRequires: python3-setuptools
BuildArch: noarch
Requires: file-libs = %{version}-%{release}
Provides: python3-magic = %{version}-%{release}
Obsoletes: python3-magic < %{version}-%{release}

%description -n python3-file-magic
This package contains the Python 3 bindings to allow access to the
libmagic API. The libmagic library is also used by the familiar
file(1) command.
%endif

%prep
%autosetup -p1

iconv -f iso-8859-1 -t utf-8 < doc/libmagic.man > doc/libmagic.man_
touch -r doc/libmagic.man doc/libmagic.man_
mv doc/libmagic.man_ doc/libmagic.man

%if %{with python3}
rm -rf %{py3dir}
cp -a python %{py3dir}
%endif

%build
# Fix config.guess to find aarch64 - #925339
autoreconf -fi

CFLAGS="%{optflags} -D_GNU_SOURCE -D_FILE_OFFSET_BITS=64 -D_LARGEFILE_SOURCE" \
%configure --enable-fsect-man5 --disable-rpath --enable-static --disable-libseccomp
export LD_LIBRARY_PATH=$PWD/src/.libs
%make_build
%if %{with python3}
cd %{py3dir}
CFLAGS="%{optflags}" %{__python3} setup.py build
%endif

%install
mkdir -p ${RPM_BUILD_ROOT}%{_datadir}/file
%make_install

# local magic in /etc/magic
mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}
cp -a ./magic/magic.local ${RPM_BUILD_ROOT}%{_sysconfdir}/magic

cat magic/Magdir/* > ${RPM_BUILD_ROOT}%{_datadir}/misc/magic
ln -s misc/magic ${RPM_BUILD_ROOT}%{_datadir}/magic
ln -s ../magic ${RPM_BUILD_ROOT}%{_datadir}/file/magic

%if %{with python3}
cd %{py3dir}
%{__python3} setup.py install -O1 --skip-build --root ${RPM_BUILD_ROOT}
%endif

%generate_compatibility_deps

%check
export LD_LIBRARY_PATH=$PWD/src/.libs
make -C tests check

%files
%license COPYING
%{_bindir}/*
%{abidir}/*-option.list
%{_mandir}/man1/*
%config(noreplace) %{_sysconfdir}/magic

%files doc
%doc ChangeLog

%files libs
%dir %{abidir}
%license COPYING
%doc ChangeLog
%{_libdir}/*so.*
%{abidir}/*.dump
%{_datadir}/magic*
%{_mandir}/man5/*
%{_datadir}/file
%{_datadir}/misc/*

%files devel
%{_libdir}/*.so
%{_includedir}/magic.h
%{_mandir}/man3/*
%{_libdir}/pkgconfig/libmagic.pc

%files static
%{_libdir}/libmagic.a


%if %{with python3}
%files -n python3-file-magic
%license COPYING
%doc python/README.md python/example.py
%{python3_sitelib}/magic.py
%{python3_sitelib}/*egg-info
%{python3_sitelib}/__pycache__/*
%endif

%changelog
* Thu Apr 20 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 5.44-2
- readelf: remove limit check

* Tue Dec 27 2022 Funda Wang <fundawang@yeah.net> - 5.44-1
- New version 5.44

* Mon Dec 5 2022 Funda Wang <fundawang@yeah.net> - 5.43-1
- New version 5.43

* Fri Oct 28 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 5.41-3
- optimise spec file

* Fri Sep 30 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 5.41-2
- add doc package

* Wed Mar 09 2022 pangqing <pangqing@uniontech.com> - 5.41-1 
- Init for anolisOS 23

